.. shorttext documentation master file, created by
   sphinx-quickstart on Fri Nov 11 18:11:01 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Homepage of `shorttext`
=======================

This repository is a collection of algorithms for multi-class classification to short texts using Python.
Modules are backward compatible unless otherwise specified. Feel free to give suggestions or report
issues through the Issue_ tab of the Github_ page. This is a PyPI_ project. This is an open-source
project under the `MIT License
<https://github.com/stephenhky/PyShortTextCategorization/blob/master/LICENSE>`_ .

Contents:

.. toctree::
   :maxdepth: 1

   intro
   install
   tutorial
   scripts
   codes
   faq
   refs
   links
   news

.. _Github: https://github.com/stephenhky/PyShortTextCategorization
.. _Issue: https://github.com/stephenhky/PyShortTextCategorization/issues
.. _PyPI: https://pypi.org/project/shorttext/

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

